#
# spec file for package quadrapassel
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           quadrapassel
Version:        40.2
Release:        1.15
Summary:        Tetris Game for GNOME
License:        GPL-2.0-or-later
Group:          Amusements/Games/Action/Other
URL:            https://live.gnome.org/Quadrapassel
Source0:        https://download.gnome.org/sources/quadrapassel/40/%{name}-%{version}.tar.xz

BuildRequires:  fdupes
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala >= 0.24.0
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(clutter-1.0) >= 1.0.0
BuildRequires:  pkgconfig(clutter-gtk-1.0) >= 0.91.6
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gsound) >= 1.0.2
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.12.0
BuildRequires:  pkgconfig(librsvg-2.0) >= 2.32.0
BuildRequires:  pkgconfig(manette-0.2)

%description
Quadrapassel is a version of Tetris, the classic game of interlocking
four-piece blocks. As they fall from the top, the player must orient
them to fit the other blocks at the bottom so that they form a
complete horizontal line, in which case that line disappears and the
player gains points

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}

%check
%meson_test

%files
%license COPYING
%doc NEWS
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/metainfo/org.gnome.Quadrapassel.appdata.xml
%{_datadir}/applications/org.gnome.Quadrapassel.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.Quadrapassel.gschema.xml
%{_datadir}/icons/hicolor/*/apps/org.gnome.Quadrapassel*
%{_mandir}/man6/%{name}.6%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Fri Jun 11 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.2:
  + Reduced the size of the border so shapes start at the top of
    the playing area.
* Tue May 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.1:
  + Press return to restart game.
  + Updated translations.
* Tue Oct  6 2020 dimstar@opensuse.org
- Update to version 3.38.1:
  + Updated game description to provide a better description.
  + Fix for incorrect preview shape when difficult blocks is
    selected.
  + Set application avatar in Gitlab.
  + Updated translations.
* Thu Aug 13 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.05:
  + Updated translations.
* Sun Aug  9 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.04:
  + Update to the icon.
  + Let the input delay for fast movement be configurable.
  + Change "piece" to "block".
  + Updated translations.
* Mon Apr 27 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.02:
  + Updated translations.
* Wed Mar 11 2020 mgorse@suse.com
- Update to version 3.36.00:
  + No changes.
* Mon Mar  2 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.35.92:
  + Defect fix to ensure keys are always unique when they are
    configured using the settings.
  + Updated translations.
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 3.35.90:
  + Updated translations.
- Changes from version 3.35.3:
  + Updates to help.
- Changes from version 3.35.2:
  + Correctly added the dependancy for the library m (libm).
  + Added the TODOs to define a short-term roadmap for the game.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Mon Oct  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Snap, updated the YAML to using the GNOME extension.
  + Updated translations.
* Sun Sep 15 2019 mgorse@suse.com
- Update to version 3.34.0:
  + Updated translations.
* Tue Sep 10 2019 mgorse@suse.com
- Update to version 3.33.90:
  + Switch from libcanberra-gtk to gsound.
  + Updated translations.
- Remove pkgconfig(libcanberra-gtk3) from BuildRequires, and add
  pkgconfig(gsound).
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Fri Feb 15 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Use --no-net for the AppStream validation test.
  + Miscellaneous cleanup.
  + Updated translations.
- Add new check section to spec and run meson_test macro.
* Tue Jan  8 2019 bjorn.lie@gmail.com
- Update to version 3.31.4:
  + Fix and restore preview in difficult mode. Note that the
    preview lies to you in this mode.
  + Fix apparent freeze in difficult mode.
  + Convert from autotools to meson.
  + Consistently use org.gnome.Quadrapassel app id.
  + Miscellaneous fixes.
  + Updated translations.
- Switch to meson buildsystem, add meson BuildRequires and macros.
- Drop hicolor-icon-theme BuildRequires: No longer needed.
* Sat Jan  5 2019 bjorn.lie@gmail.com
- Update to version 3.31.3:
  + Add game controller support using libmanette.
  + Update menus for GNOME 3.32 recommendations.
  + Pressing Pause will start a new game if no game has started
    yet.
  + Stop using intltool.
  + Miscellaneous fixes.
- Drop intltool >= 0.50 BuildRequires: No longer needed.
- Drop post(un) handling of glib2_gsettings_schema_post(un),
  desktop_database_post(un) and icon_theme_cache_post(un) and drop
  glib2_gsettings_schema_requires, no longer needed.
- Drop update-desktop-files BuildRequires and
  suse_update_desktop_file macro, no longer needed.
- Add fdupes BuildRequires and macro, remove duplicate files.
- Add pkgconfig(manette-0.2) BuildRequires: New dependency.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Sep 21 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Mon Aug 15 2016 zaitor@opensuse.org
- Update to version 3.21.90:
  + Removed rtl icon code.
  + Add Language headers to po files.
  + Updated translations.
* Sat May 28 2016 zaitor@opensuse.org
- Update to version 3.21.2:
  + Don't save last scores twice before exiting.
  + Updated translations.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + No changes, version bump only.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Updated translations.
* Tue Feb 16 2016 dimstar@opensuse.org
- Update to version 3.19.90:
  + Stop using deprecated gnome-common.
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Tue Sep 15 2015 zaitor@opensuse.org
- Update to version 3.17.92:
  + No changes from last version, pure version bump.
* Wed Sep  2 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Updated translations.
* Wed May 13 2015 zaitor@opensuse.org
- Update to version 3.16.1:
  + Add symbolic icon.
  + Updated translations.
- Remove HighContrast %%icon_theme_cache_post(un) calls, as Symbolic
  icons have replaced them.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Updated translations.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Updated translations.
* Mon Dec  1 2014 badshah400@gmail.com
- Update to version 3.15.2:
  + Code cleanup.
  + Layout Changes.
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Mon Sep 15 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Updated translations.
* Mon Sep  1 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + Updated translations.
* Tue Aug 19 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Updated translations.
* Mon Jul 21 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Appdata Fixes.
  + General Fixup.
  + Updated translations.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.13.1:
  + Mark all images without translatable text as non-translatable.
  + Updated user docs.
  + Updated translations.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Updated translations.
* Tue Apr 15 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Updated translations.
* Sun Mar 23 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Tue Mar 18 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Updated translations.
* Mon Mar  3 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Updated translations.
* Mon Feb 17 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + appdata: specify project_group.
  + Add tooltips to the pause/play button.
  + Updated translations.
* Mon Feb  3 2014 zaitor@opensuse.org
- Update to version 3.11.5:
  + Remove Pause from the app menu.
  + Redone Layout, Removed toolbar and fullscreen mode, added
    headerbar.
  + Add multi-functional button (new game, pause, unpause).
  + Change GTK dependency to 3.10.
  + Change default window size to something nicer looking.
  + Fix the start icon in RTL.
  + Updated translations.
* Mon Jan 13 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + About dialog: update website.
  + Updated translations.
* Mon Dec 16 2013 dimstar@opensuse.org
- Update to version 3.11.3:
  + Added frame around preview area.
  + Score dialog: autoscroll to new score.
  + Split ScoreDialog into its own file.
  + Scores dialog: replace Quit with Close.
  + About dialog: switch to GtkLicense.
  + app menu: standardize Help/About/Quit.
  + Updated translations.
* Mon Nov 18 2013 dimstar@opensuse.org
- Update to version 3.11.2:
  + Check for *-validate before using it.
  + Run autoupdate.
  + Sort scores from highest to lowest.
  + Make preview area available at the start of the game (if it is
    enabled).
  + Changing text layout of sidebar.
  + Updated translations.
* Sun Nov 17 2013 dimstar@opensuse.org
- Update to version 3.11.1:
  + Disable all C warnings.
  + Stop using deprecated Gtk.Stock.
  + Remove .desktop.in.in and BugBuddy info.
  + Rely on intltool >=0.50 for gsettings translation.
  + Changes in appdata file.
  + Update screenshot for new appdata-validate.
  + Use the dark theme.
  + Updated translations.
* Mon Nov 11 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + Sort scores from highest to lowest.
* Sun Sep 22 2013 zaitor@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Mon Sep 16 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Add an appdata file.
  + Reset pause button when game starts.
  + Remove earthquake and make falling slower and more realistic.
  + Fix issue with pre filled Lines.
  + Give stage lighter color.
  + Updated translations.
* Sun Sep  1 2013 zaitor@opensuse.org
- Update to version 3.9.91:
  + Updated translations.
* Sun Aug 18 2013 zaitor@opensuse.org
- Update to version 3.9.90:
  + Update git.mk and ignore more files.
  + Updated translations.
* Wed Jul 31 2013 zaitor@opensuse.org
- Update to version 3.9.5:
  + Removed deprecated clutter animation.
  + Don't choose difficult blocks by default.
  + Switch preview and difficult blocks in settings.
  + help: add missing space between icon and title.
  + help: Fix obsolete product of bugzilla.
  + Updated translations.
* Sun Jul 28 2013 zaitor@opensuse.org
- Update to version 3.8.2:
  + Fixed repeated down press bug.
  + Hiding preview embed when preview is unavailable or disabled.
  + Disable preview-button in difficult block mode.
  + Fix bug where falling block shadow would get missing.
  + Fix segmentation fault when down key was released after game
    was over.
  + help: update translate  link for new module name.
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Fix tags in the Hungarian help.
  + Updated translations.
* Wed Mar 27 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Fixed high contrast icon for 256x256.
  + Updated translations.
* Tue Mar  5 2013 dimstar@opensuse.org
- Initial package, version 3.7.90: split-off from gnome-games.
